Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(980)

Unified Diff: Source/core/layout/svg/SVGLayoutSupport.h

Issue 1033943002: Rename LayoutStyle to papayawhip (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: ensureComputedStyle Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/layout/svg/ReferenceFilterBuilder.cpp ('k') | Source/core/layout/svg/SVGLayoutSupport.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/svg/SVGLayoutSupport.h
diff --git a/Source/core/layout/svg/SVGLayoutSupport.h b/Source/core/layout/svg/SVGLayoutSupport.h
index 6c5384a1bf08a31bc9318bc90d43ebee46f4d039..4258ff7df729f6b034c52aae99baddf5964e3fda 100644
--- a/Source/core/layout/svg/SVGLayoutSupport.h
+++ b/Source/core/layout/svg/SVGLayoutSupport.h
@@ -40,7 +40,7 @@ struct PaintInfo;
class LayoutGeometryMap;
class LayoutBoxModelObject;
class LayoutObject;
-class LayoutStyle;
+class ComputedStyle;
class LayoutSVGRoot;
class SVGLengthContext;
class StrokeData;
@@ -80,15 +80,15 @@ public:
static const LayoutObject* pushMappingToContainer(const LayoutObject*, const LayoutBoxModelObject* ancestorToStopAt, LayoutGeometryMap&);
// Shared between SVG layoutObjects and resources.
- static void applyStrokeStyleToContext(GraphicsContext&, const LayoutStyle&, const LayoutObject&);
- static void applyStrokeStyleToStrokeData(StrokeData&, const LayoutStyle&, const LayoutObject&);
+ static void applyStrokeStyleToContext(GraphicsContext&, const ComputedStyle&, const LayoutObject&);
+ static void applyStrokeStyleToStrokeData(StrokeData&, const ComputedStyle&, const LayoutObject&);
- static DashArray resolveSVGDashArray(const SVGDashArray&, const LayoutStyle&, const SVGLengthContext&);
+ static DashArray resolveSVGDashArray(const SVGDashArray&, const ComputedStyle&, const SVGLengthContext&);
// Update the GC state (on |paintInfo.context|) for painting |layoutObject|
// using |style|. |resourceMode| is used to decide between fill/stroke.
// Previous state will be saved (if needed) using |stateSaver|.
- static bool updateGraphicsContext(const PaintInfo&, GraphicsContextStateSaver&, const LayoutStyle&, LayoutObject&, LayoutSVGResourceMode, const AffineTransform* additionalPaintServerTransform = 0);
+ static bool updateGraphicsContext(const PaintInfo&, GraphicsContextStateSaver&, const ComputedStyle&, LayoutObject&, LayoutSVGResourceMode, const AffineTransform* additionalPaintServerTransform = 0);
// Determines if any ancestor's transform has changed.
static bool transformToRootChanged(LayoutObject*);
@@ -100,8 +100,8 @@ public:
// can/will be laid out as part of a <text>.
static bool isLayoutableTextNode(const LayoutObject*);
- // Determines whether a svg node should isolate or not based on LayoutStyle.
- static bool willIsolateBlendingDescendantsForStyle(const LayoutStyle&);
+ // Determines whether a svg node should isolate or not based on ComputedStyle.
+ static bool willIsolateBlendingDescendantsForStyle(const ComputedStyle&);
static bool willIsolateBlendingDescendantsForObject(const LayoutObject*);
template<typename LayoutObjectType>
static bool computeHasNonIsolatedBlendingDescendants(const LayoutObjectType*);
« no previous file with comments | « Source/core/layout/svg/ReferenceFilterBuilder.cpp ('k') | Source/core/layout/svg/SVGLayoutSupport.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698